const AWS = require('aws-sdk');

class AWSLambdaCaller {
    constructor(awsConfig) {
        AWS.config.update(awsConfig);
    }

    call(jsonObj, functionName) {
        const lambda = new AWS.Lambda();

        const params = {
            FunctionName: functionName,
            Payload: JSON.stringify(jsonObj)
        };
        try {
            const lambdaInvokeResp = lambda.invoke(params).promise();
            return lambdaInvokeResp.then((value) => {
                return JSON.parse(value.Payload);
            });

        } catch (e) {
            console.log(e);
            console.warn('Error, cannot invoke lambda ' + functionName);
        }
    }
}

module.exports = AWSLambdaCaller;
